sa.ms_function(y, x, tau=0.5, start,lb,ub, rt=0.15, eps=1.0E-6,
       ns=10, nt=20, int=T, neps=4, maxevl=10000000, sl, vm, seed1=1,
       seed2=2, t=10, output=1, sgn=1)
{
if(!is.loaded(symbol.For("sams"))) dyn.load("sams.o")
x <- as.matrix(x)
if(int) x <- cbind(1,x)
y <- as.vector(y)
nobs <- nrow(x)
k <- ncol(x)

if(missing(start)) {
prob.mod<-glm(y~1+x,family=binomial(link=probit))
start <- coef(prob.mod)/coef(prob.mod)[k]}
else{start <- as.vector(start)}

if(missing(lb)) {lb <- c(rep(-5, k),1)}
if(missing(ub)) {ub <- c(rep(5, k),1)}

for(i in 1:k) {
   if(start[i]<lb[i] | start[i]>ub[i]) stop("The starting values
(start) are out of bounds. Respecify start and/or lb and ub so
that -1 < start(i) < 1,  i=1,..,k") }

if(missing(sl)) {sl <- rep(2, k)}
if(missing(vm)) {vm <- rep(1, k)}

if(seed1<0 | seed1>31328 | seed2<0 | seed2>30081)
    stop("The first number seed (seed1) must have a value between 0
and 31328 and the second value seed (seed2) must have a value between
0 and 30081.")

if(t<=0) stop(" The initial temperature (t) is not positive.
Reset t to a positive number.")

if(output!=1 & output!=2) stop("There are only two possible forms
of output : 1 for the coefficient vector normalized to have norm equal
to one, and 2 for the coefficient vector normalized so that it's last
element is set to one.")

out1 <- .Fortran("fcn",
         as.double(y),
         as.double(x),
         as.integer(nobs),
         as.integer(k),
         start = as.double(start),
         obj = as.double(0),
         tau = as.double(tau),
	 as.double(sgn)
         )

# print("starting values and the value of the score function at them")
first <- list(tau=out1$tau, start=out1$start, obj=out1$obj)
print(first)

# print("values after SA:")
out2 <- .Fortran("sa",
         as.double(y),
         as.double(x),
         as.integer(nobs),
         as.integer(k),
         as.double(start),
         tau = as.double(tau),
         as.logical(T),
         as.double(rt),
         as.double(eps),
         as.integer(ns),
         as.integer(nt),
         as.integer(neps),
         as.integer(maxevl),
         as.double(lb),
         as.double(ub),
         as.double(sl),
         as.double(seed1),
         as.double(seed2),
         as.double(t),
         as.double(vm),
         coef = as.double(start),
         obj = as.double(0),
         as.integer(0),
         as.integer(0),
         as.integer(0),
         as.integer(0),
         as.double(start),
         as.double(start),
         as.integer(start),
         aflag = as.integer(0),
	 as.double(sgn)
         )

if(out2$aflag!=0)
    warning("Too many function evaluations. Consider increasing maxevl
             or eps, or decreasing nt or rt. These results are likely
             to be poor.")

beta <- out2$coef

if (output==2){
   norm <- sqrt(sum(beta^2))
   beta <- beta / norm
   }

final<-list(tau=out2$tau, coef=beta, obj=out2$obj)

return(unlist(first),unlist(final))
#return(out2)
}
